local fs  = require "nixio.fs"
local has_ftpput = fs.access("/usr/bin/ftpput")
local has_wput = fs.access("/usr/bin/wput")

m = Map("ftpbackup", translate("FTP backup"))

s = m:section(TypedSection, "ftpbackup", "FTPBackup")
s.anonymous = true

s:tab("general",  translate("General Settings"))

s:taboption("general", Flag, "enabled", translate("Enabled"))

s:taboption("general", Value, "hostname", translate("Hostname"))
s:taboption("general", Value, "username", translate("User name"))
pass=s:taboption("general", Value, "password", translate("Password"))
pass.password = true
port=s:taboption("general", Value, "port", translate("Port"))
port.default = 21
timeformat = s:taboption("general", Value, "timeformat", translate("Timestamp format"), translate("date like format"))
timeformat.default = "+%Y%m%d%H%M%S"

cron = s:taboption("general", Value, "cron", translate("Backup interval"), translate("crontab like format"))

cron.default = "0 0 * * *"

cron:value("0 0 * * *", "00:00 on every day")
cron:value("0 0 * * 1", "00:00 on every monday")
cron:value("0 0 * * 2", "00:00 on every tuesday")
cron:value("0 0 * * 3", "00:00 on every wednesday")
cron:value("0 0 * * 4", "00:00 on every thursday")
cron:value("0 0 * * 5", "00:00 on every friday")
cron:value("0 0 * * 6", "00:00 on every saturday")
cron:value("0 0 * * 0", "00:00 on every sunday")
cron:value("0 0 1 * *", "00:00 on 1st of each month")
cron:value("0 * * * *", "every hour")
cron:value("*/30 * * * *", "every 30 minutes")
cron:value("*/10 * * * *", "every 10 minutes")
cron:value("*/5 * * * *", "every 5 minutes")
cron:value("*/1 * * * *", "every minute")

--[[
function cron.cfgvalue(self, section)
	value = luci.sys.exec("cat /etc/crontabs/root | grep ftpbackup | cut -f-5 -d ' '")
	#if string.len(value)<2 then
	#	value = "0 0 * * *"
	#end
	return value
end
]]--

function cron.write(self, section, value)
	Value.write(self, section, value)
	luci.sys.exec("sed -i '/ftpbackup/d' /etc/crontabs/root")
	local fd = io.open("/etc/crontabs/root", "a")
	value = value .. " /etc/vargalex/ftpbackup > /dev/null 2>&1\n"
	fd:write(value)
	fd:close()
end

wdir = s:taboption("general", Value, "workdir", translate("Working directory"))
wdir:value("/tmp","/tmp")
wdir:value("/mnt","/mnt")
wdir.default = "/tmp"

bin = s:taboption("general", ListValue, "binary", translate("FTP client program"))
if has_ftpput then
	bin:value("/usr/bin/ftpput", "ftpput")
end
if has_wput then
	bin:value("/usr/bin/wput", "wput")
end

s:taboption("general", Value, "parameters", translate("FTP client additional options"))

s:taboption("general", Flag, "logging", translate("Logging"))                
                                                        
s = m:section(TypedSection, "backup", translate("Backup entries"))
s.anonymous = true
s.addremove = true
s.template = "cbi/tblsection"

s:option(Flag, "enabled", translate("Enabled"))
backuptype = s:option(ListValue, "sourcetype", "Source type")
backuptype:value("f", "File/Directory")
backuptype:value("c", "Command output")
backuptype.default="f"

s:option(Value, "source", translate("Source"))

s:option(Value, "target", translate("Target filename"))

time = s:option(Flag, "timestamp", translate("Add timestamp to target filename"))

comp = s:option(Flag, "compress", translate("Compress"))

return m
